# Examples

**All examples are fully documented in [https://wrapyfi.readthedocs.io/en/latest/examples.html](https://wrapyfi.readthedocs.io/en/latest/examples.html)**

To install the examples' requirements 

```
pip3 install requirements.txt -r 
```

All python scripts in this directory are runnable. Each script contains instructions on running the process under `Run`

For all scripts (with Yarp) the `yarpserver` command must be running in a standalone terminal.

For all scripts (with ROS) the `roscore` command must be running in a standalone terminal.
